@@ -28,7 +28,6 @@
 #include "action_data/simple_action_data.h"
 
 #include <QDebug>
-#include <KUrl>
 
 #include <QSignalMapper>
 #include <QContextMenuEvent>
@@ -245,7 +244,7 @@ void HotkeysTreeViewContextMenu::exportAction()
             }
 
         QString id = widget->importId();
-        KUrl url   = widget->url();
+        QUrl url   = widget->url();
         bool allowMerging = widget->allowMerging();
         if (!url.isEmpty())
             {
@@ -308,8 +307,8 @@ void HotkeysTreeViewContextMenu::newGlobalShortcutActionAction( int actionType )
         }
 
     KHotKeys::SimpleActionData *data =
-        new KHotKeys::SimpleActionData( 0, i18n("New Action"), i18n("Comment"));
-    data->set_trigger( new KHotKeys::ShortcutTrigger( data, KShortcut() ) );
+        new KHotKeys::SimpleActionData( nullptr, i18n("New Action"), i18n("Comment"));
+    data->set_trigger( new KHotKeys::ShortcutTrigger( data, QKeySequence() ) );
     data->enable();
 
     createActionFromType(actionType, data);
@@ -337,7 +336,7 @@ void HotkeysTreeViewContextMenu::newMouseGestureTriggerActionAction( int actionT
         }
 
     KHotKeys::SimpleActionData *data =
-        new KHotKeys::SimpleActionData( 0, i18n("New Action"), i18n("Comment"));
+        new KHotKeys::SimpleActionData( nullptr, i18n("New Action"), i18n("Comment"));
     data->set_trigger( new KHotKeys::GestureTrigger(data) );
     data->enable();
 
@@ -366,7 +365,7 @@ void HotkeysTreeViewContextMenu::newWindowTriggerActionAction( int actionType )
         }
 
     KHotKeys::SimpleActionData *data =
-        new KHotKeys::SimpleActionData( 0, i18n("New Action"), i18n("Comment"));
+        new KHotKeys::SimpleActionData( nullptr, i18n("New Action"), i18n("Comment"));
     data->set_trigger( new KHotKeys::WindowTrigger(data) );
     data->enable();
 
