@@ -32,7 +32,8 @@
 
 #include <QDebug>
 #include <KGlobalAccel>
-#include <KShortcut>
+#include <KLocalizedString>
+#include <QKeySequence>
 
 #include <QAction>
 #include <QUuid>
@@ -46,6 +47,7 @@ ShortcutsHandler::ShortcutsHandler( HandlerType type, QObject *parent )
          ,_type(type)
          ,_actions(new KActionCollection(this, QStringLiteral("khotkeys")))
     {
+    _actions->setComponentDisplayName(i18n("Custom Shortcuts Service"));
     connect(KGlobalAccel::self(), &KGlobalAccel::globalShortcutChanged, this, &ShortcutsHandler::shortcutChanged);
     }
 
@@ -60,7 +62,7 @@ ShortcutsHandler::~ShortcutsHandler()
 QAction *ShortcutsHandler::addAction(
         const QString &id,
         const QString &text,
-        const KShortcut &shortcut )
+        const QKeySequence &shortcut )
     {
 #ifdef KHOTKEYS_TRACE
     qDebug() << id << text << shortcut;
@@ -79,7 +81,7 @@ QAction *ShortcutsHandler::addAction(
     QAction *newAction = _actions->addAction(realId);
     if (!newAction)
         {
-        return 0;
+        return nullptr;
         }
     // If our HandlerType is configuration we have to tell kdedglobalaccel
     // that this action is only for configuration purposes.
@@ -89,14 +91,14 @@ QAction *ShortcutsHandler::addAction(
         newAction->setProperty("isConfigurationAction", QVariant(true));
         }
     newAction->setText(text);
-    KGlobalAccel::self()->setShortcut(newAction, QList<QKeySequence>() << shortcut.primary());
+    KGlobalAccel::self()->setShortcut(newAction, QList<QKeySequence>() << shortcut);
     // Enable global shortcut. If that fails there is no sense in proceeding
     if (!KGlobalAccel::self()->hasShortcut(newAction))
         {
         qWarning() << "Failed to enable global shortcut for '" 
                    << text << "' " << id;
         _actions->removeAction(newAction);
-        return 0;
+        return nullptr;
         }
     Q_ASSERT(newAction->isEnabled());
 
