@@ -27,7 +27,7 @@
 
 
 class KAction;
-class KShortcut;
+class QKeySequence;
 
 namespace KHotKeys {
 
@@ -49,7 +49,7 @@ public:
      *
      * \param Should 
      */
-    ShortcutsHandler( HandlerType type = Active, QObject *parent = 0 );
+    ShortcutsHandler( HandlerType type = Active, QObject *parent = nullptr );
 
     /**
      * Destructor
@@ -73,7 +73,7 @@ public:
     QAction *addAction(
         const QString &id,
         const QString &text,
-        const KShortcut &shortcut );
+        const QKeySequence &shortcut );
 
     /**
      * Remove a action from the collection.
