@@ -188,7 +188,7 @@ void Voice::slot_sound_recorded(const Sound &sound_P)
 */
 
 
-void Voice::set_shortcut( const KShortcut &shortcut)
+void Voice::set_shortcut( const QKeySequence &shortcut)
 {
     _shortcut = shortcut;
     if( !_enabled )
